2.019: blessing 2.018.21 as the new release. 2.019 debian/2%2.019-1
authorFrancois-Rene Rideau <fare@tunes.org>
Mon, 28 Nov 2011 00:10:58 +0000 (19:10 -0500)
committerFrancois-Rene Rideau <fare@tunes.org>
Mon, 28 Nov 2011 00:10:58 +0000 (19:10 -0500)
asdf.asd
asdf.lisp
debian/changelog

index 4d57a78..46d1237 100644 (file)
--- a/asdf.asd
+++ b/asdf.asd
@@ -14,7 +14,7 @@
   :licence "MIT"
   :description "Another System Definition Facility"
   :long-description "ASDF builds Common Lisp software organized into defined systems."
-  :version "2.018.21" ;; to be automatically updated by bin/bump-revision
+  :version "2.019" ;; to be automatically updated by bin/bump-revision
   :depends-on ()
   :components
   ((:file "asdf")
index 595a2f6..a95826b 100644 (file)
--- a/asdf.lisp
+++ b/asdf.lisp
@@ -1,5 +1,5 @@
 ;;; -*- mode: Common-Lisp; Base: 10 ; Syntax: ANSI-Common-Lisp -*-
;;; This is ASDF 2.018.21: Another System Definition Facility.
 ;;;
 ;;; Feedback, bug reports, and patches are all welcome:
 ;;; please mail to <asdf-devel@common-lisp.net>.
          ;; "2.345.6" would be a development version in the official upstream
          ;; "2.345.0.7" would be your seventh local modification of official release 2.345
          ;; "2.345.6.7" would be your seventh local modification of development version 2.345.6
-         (asdf-version "2.018.21")
+         (asdf-version "2.019")
          (existing-asdf (find-class 'component nil))
          (existing-version *asdf-version*)
          (already-there (equal asdf-version existing-version)))
index a0284e0..e8c49d5 100644 (file)
@@ -1,3 +1,38 @@
+cl-asdf (2:2.019-1) unstable; urgency=low
+
+  * UI: Create and use a load-systems abstraction,
+   in view of using it in a system-granular parallelizing backend. (.15)
+  * Usability: when a system can't be found, there's now a restart to retry
+   finding a system after reinitializing the source-registry (.10).
+  * Feature: :around-compile now accepts lambda expressions, and also strings,
+   so you can specify future wrappers that can't even be read yet. (.11, .12).
+  * Filesystem: recursing through logical pathnames in LispWorks (.2, .3),
+   on SBCL as on CMUCL, have asdf:subdirectories follow symlinks (.8., .9)
+  * Configuration: modify user-configuration-directories and
+   system-configuration-directories to return all valid directory names
+   even when they don't exist yet so you may create them (.6), also output
+   name of non-existing configuration file when opening them for writing (.7),
+  * Internals: strcat (.5), split locate-systems from find-systems (.6)
+  * Portability: Debugged CormanLisp support (.1).
+   Fix type declaration for SCL (.17).
+  * Bug fix: don't drop pathname components without a / at the end
+   when reading a path using GETENV (.18). (Bug from 2.017.27)
+  Closes: #647544.
+  * Bug fix: don't redefine reinitialize-instance in ways that break
+   its contract and its clients (such as asdf-dependency-grovel).
+   Use change-class to reset slots (.16), but not to 'standard-object,
+   which breaks ecl, rather to a proto-system class (.19), and not
+   using keys with breaks genera (.21). (Bug from 2.017.3)
+  * Bug fix: buglet in maybe-add-tree (.4)
+  * Upgrade: unintern internals of signature changed in 2.017.12 (.13),
+   have *system-definition-search-functions* not be a defparameter,
+   but a defvar with a fixup (.14), clear *systems-being-defined* when
+   upgrading asdf but re-find them immediately because they may be needed
+   as part of a higher operation (.14).
+   Unintern some more functions that have changed signature (.20).
+
+ -- Francois-Rene Rideau <fare@tunes.org>  Sun, 27 Nov 2011 16:09:42 -0500
+
 cl-asdf (2:2.018-1) unstable; urgency=low
 
   Bugs:
@@ -1,5 +1,5 @@
 ;;; -*- mode: Common-Lisp; Base: 10 ; Syntax: ANSI-Common-Lisp -*-
-;;; This is ASDF 2.018.21: Another System Definition Facility.
+;;; This is ASDF 2.019: Another System Definition Facility.
 ;;;
 ;;; Feedback, bug reports, and patches are all welcome: